@@ -59,6 +59,8 @@ def load(dependencies, override=False):
 
 
 def load_config(filenames=['etc/ioc.conf', 'etc/ioc.conf.d/*'], override=True):
+    if isinstance(filenames, str):
+        filenames = [filenames]
     for filepath in itertools.chain(*[glob.glob(x) for x in filenames]):
         with open(filepath) as f:
             load(yaml.safe_load(f.read()), override=override)
